@@ -15,14 +15,13 @@ sub fitness_M0 ($antibody_genome, @args) {
 
 	my $genome = $antibody_genome->genome_complement($antigen_genome);
 
-	### FIXME use count perlism
-	for (my $i = 0; $i < scalar $genome->{genes}; $i++) {
-		if ($genome->{genes}[$i]) {
-			$sum ++;
-		}	
-	}	
-	
-	return $sum;
+	return bitcount($genome->{genes});
+}
+
+### count all bits of 1 in a genome
+sub bitcount(@l) {
+	my $sum = 0;
+	return grep { $_ and $sum++ } @_ and $sum;
 }
 
 1;
